pub struct DebugControl { /* private fields */ }Expand description
A controller used to manage breakpoints and execution flow for a running Axon.
This is typically stored in the Bus to allow the Axon runtime to check
for pause-points between node executions.
Implementations
Sourceimpl DebugControl
impl DebugControl
Sourcepub fn set_breakpoint(&self, node_id: String)
pub fn set_breakpoint(&self, node_id: String)
Add a breakpoint for a specific node ID.
Sourcepub fn remove_breakpoint(&self, node_id: &str)
pub fn remove_breakpoint(&self, node_id: &str)
Remove a breakpoint for a specific node ID.
Sourcepub fn should_pause(&self, node_id: &str) -> bool
pub fn should_pause(&self, node_id: &str) -> bool
Check if the current node should trigger a pause.
This consumes the internal “pause_next” flag if it was set.
Sourcepub async fn wait_if_needed(&self, node_id: &str)
pub async fn wait_if_needed(&self, node_id: &str)
Check if the current node requires a pause and wait if so.
Deprecated in favor of manual should_pause + wait for better event timing.
Sourcepub fn state(&self) -> DebugState
pub fn state(&self) -> DebugState
Get the current debugger state.
Sourcepub fn list_breakpoints(&self) -> Vec<String>
pub fn list_breakpoints(&self) -> Vec<String>
List all currently set breakpoint node IDs.